@@ -599,7 +599,7 @@ def _generate_router(project_root: Path, project_name: str, name: str) -> None:
             click.echo(f"   Create it: mkdir -p {web_path / 'routes'}")
         else:
             click.echo("   Router generation requires Vega Web module")
-            click.echo("   Install it with: vega add web")
+            click.echo("   Web support is included by default in new projects (vega init <name>)")
         return
 
     # Convert name to appropriate formats
@@ -652,7 +652,7 @@ def _generate_web_models(project_root: Path, project_name: str, name: str, is_re
             click.echo(f"   Model generation requires web structure in context '{context}'")
         else:
             click.echo("   Model generation requires Vega Web module")
-            click.echo("   Install it with: vega add web")
+            click.echo("   Web support is included by default in new projects (vega init <name>)")
         return
 
     # Validate flags
@@ -672,11 +672,6 @@ def _generate_web_models(project_root: Path, project_name: str, name: str, is_re
     models_path = web_path / "models"
     models_path.mkdir(exist_ok=True)
 
-    # Ensure __init__.py exists
-    init_file = models_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text('"""Pydantic models for API validation"""\n')
-
     # Convert name to PascalCase for class names
     model_name = to_pascal_case(name)
     model_file = to_snake_case(model_name)
@@ -743,7 +738,7 @@ def _generate_middleware(project_root: Path, project_name: str, class_name: str,
     if not web_path.exists():
         click.echo(click.style("ERROR: Web module not found", fg='red'))
         click.echo("   Middleware generation requires Vega Web module")
-        click.echo("   Install it with: vega add web")
+        click.echo("   Web support is included by default in new projects (vega init <name>)")
         return
 
     # Remove 'Middleware' suffix if present to avoid duplication
@@ -756,12 +751,6 @@ def _generate_middleware(project_root: Path, project_name: str, class_name: str,
     middleware_path = web_path / "middleware"
     middleware_path.mkdir(exist_ok=True)
 
-    # Check if __init__.py exists
-    init_file = middleware_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text('"""Vega Web Middlewares"""\n')
-        click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
-
     # Generate middleware file
     middleware_file = middleware_path / f"{file_name}.py"
 
@@ -820,12 +809,6 @@ def _generate_sqlalchemy_model(project_root: Path, project_name: str, class_name
     models_path = project_root / "infrastructure" / "models"
     models_path.mkdir(exist_ok=True)
 
-    # Check if __init__.py exists in models directory
-    init_file = models_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text('"""SQLAlchemy models"""\n')
-        click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
-
     # Generate model file
     model_file = models_path / f"{file_name}.py"
 
@@ -1048,9 +1031,7 @@ def _generate_event(project_root: Path, project_name: str, class_name: str, file
     events_path = base_path / "domain" / "events"
     events_path.mkdir(parents=True, exist_ok=True)
 
-    init_file = events_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text("")
+    # No need to create empty __init__.py
 
     file_path = events_path / f"{file_name}.py"
     if file_path.exists():
@@ -1092,10 +1073,6 @@ def _generate_event_handler(project_root: Path, project_name: str, class_name: s
     handlers_path = project_root / "events"
     handlers_path.mkdir(parents=True, exist_ok=True)
 
-    init_file = handlers_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text("")
-
     handler_file = handlers_path / f"{file_name}.py"
     if handler_file.exists():
         click.echo(click.style(f"ERROR: Error: {handler_file.relative_to(project_root)} already exists", fg='red'))
@@ -1151,10 +1128,6 @@ def _generate_listener(project_root: Path, project_name: str, class_name: str, f
     listeners_path = project_root / "infrastructure" / "listeners"
     listeners_path.mkdir(parents=True, exist_ok=True)
 
-    init_file = listeners_path / "__init__.py"
-    if not init_file.exists():
-        init_file.write_text("")
-
     listener_file = listeners_path / f"{file_name}.py"
     if listener_file.exists():
         click.echo(click.style(f"ERROR: {listener_file.relative_to(project_root)} already exists", fg='red'))
@@ -1230,14 +1203,33 @@ def _generate_context(project_root: Path, project_name: str, context_name: str):
         "infrastructure/repositories",
         "infrastructure/services",
         "presentation/cli/commands",
+        "presentation/web/routes",
+        "presentation/web/models",
     ]
 
     for directory in directories:
         dir_path = context_path / directory
         dir_path.mkdir(parents=True, exist_ok=True)
-        (dir_path / "__init__.py").write_text("")
         click.echo(f"  + Created {context_name}/{directory}/")
 
+    # Initialize web package files
+    from vega.cli.templates import (
+        render_web_package_init,
+        render_vega_routes_init_context,
+        render_pydantic_models_init
+    )
+
+    web_init_path = context_path / "presentation" / "web" / "__init__.py"
+    web_init_path.write_text(render_web_package_init())
+
+    routes_init_path = context_path / "presentation" / "web" / "routes" / "__init__.py"
+    routes_init_path.write_text(render_vega_routes_init_context(context_name, project_name))
+
+    models_init_path = context_path / "presentation" / "web" / "models" / "__init__.py"
+    models_init_path.write_text(render_pydantic_models_init())
+
+    click.echo(f"  + Initialized web package in {context_name}")
+
     # Context __init__.py with documentation
     context_init = render_context_init(context_name, project_name)
     (context_path / "__init__.py").write_text(context_init)
