@@ -48,20 +48,16 @@ def init_project(project_name: str, template: str, parent_path: str):
         "tests/lib/core/presentation",
     ]
 
-    # Add web directories if web template
-    if template in ["web", "fastapi"]:
-        directories.extend([
-            "lib/core/presentation/web/routes",
-            "lib/core/presentation/web/models",
-        ])
+    # Add web directories (always included)
+    directories.extend([
+        "lib/core/presentation/web/routes",
+        "lib/core/presentation/web/models",
+    ])
 
     for directory in directories:
         dir_path = project_path / directory
         dir_path.mkdir(parents=True, exist_ok=True)
 
-        # Create __init__.py for Python packages
-        (dir_path / "__init__.py").write_text("")
-
         # Use auto-discovery template for cli/commands
         if "cli" in directory and "commands" in directory:
             from vega.cli.templates import render_cli_commands_init
@@ -75,6 +71,11 @@ def init_project(project_name: str, template: str, parent_path: str):
 
         click.echo(f"  + Created {directory}/")
 
+    # Initialize web files in core context
+    click.echo("\n[*] Initializing Vega Web in core context")
+    from vega.cli.scaffolds import create_vega_web_scaffold_in_context
+    create_vega_web_scaffold_in_context(project_path, project_name, "core", echo=click.echo)
+
     # Create bounded context init files with documentation
     from vega.cli.templates import render_context_init
 
@@ -88,8 +89,37 @@ def init_project(project_name: str, template: str, parent_path: str):
     (project_path / "lib" / "shared" / "__init__.py").write_text(shared_init)
     click.echo(f"  + Created lib/shared/__init__.py (Shared kernel)")
 
-    # lib/__init__.py
-    (project_path / "lib" / "__init__.py").write_text("")
+    # lib/__init__.py - required for package imports
+    (project_path / "lib" / "__init__.py").write_text('"""Bounded contexts package"""\n')
+    click.echo(f"  + Created lib/__init__.py")
+
+    # Root __init__.py - required to make project a package
+    (project_path / "__init__.py").write_text(f'"""{project_name} - Vega DDD Project"""\n')
+    click.echo(f"  + Created __init__.py (root package)")
+
+    # Create package directory with normalized name (for imports)
+    # This allows the project to be imported as a Python package
+    normalized_name = project_name.replace('-', '_')
+    package_init_content = f'''"""{project_name} package
+
+This package allows the project to be imported by its normalized name.
+All modules (lib, config, etc.) are available from the parent directory.
+"""
+import sys
+from pathlib import Path
+
+# Add parent directory to path to allow imports
+_parent = Path(__file__).parent.parent
+if str(_parent) not in sys.path:
+    sys.path.insert(0, str(_parent))
+
+# Re-export commonly used modules
+from lib import *  # noqa: F401, F403
+'''
+    package_dir = project_path / normalized_name
+    package_dir.mkdir(exist_ok=True)
+    (package_dir / "__init__.py").write_text(package_init_content)
+    click.echo(f"  + Created {normalized_name}/ (package directory)")
 
     # Create config.py
     config_content = render_template("config.py.j2", project_name=project_name)
@@ -131,21 +161,10 @@ def init_project(project_name: str, template: str, parent_path: str):
     (project_path / "ARCHITECTURE.md").write_text(architecture_content, encoding='utf-8')
     click.echo(f"  + Created ARCHITECTURE.md")
 
-    # Create main.py based on template
-    # Support both "web" and "fastapi" (backward compat)
-    if template in ["web", "fastapi"]:
-        click.echo("\n[*] Adding Vega Web scaffold (presentation/web/)")
-        create_vega_web_scaffold(project_path, project_name)
-
-        # Create main.py for web project
-        main_content = render_template("main.py.j2", project_name=project_name, template="fastapi")
-        (project_path / "main.py").write_text(main_content)
-        click.echo(f"  + Created main.py (Vega Web entrypoint)")
-    else:
-        # Create standard main.py
-        main_content = render_template("main.py.j2", project_name=project_name, template="standard")
-        (project_path / "main.py").write_text(main_content)
-        click.echo(f"  + Created main.py")
+    # Create main.py for CLI commands
+    main_content = render_template("main.py.j2", project_name=project_name, template="fastapi")
+    (project_path / "main.py").write_text(main_content)
+    click.echo(f"  + Created main.py (CLI entry point)")
 
 
     # Success message with appropriate next steps
@@ -155,17 +174,11 @@ def init_project(project_name: str, template: str, parent_path: str):
     click.echo(f"  poetry install")
     click.echo(f"  cp .env.example .env")
 
-    if template in ["web", "fastapi"]:
-        click.echo(f"\nRun commands:")
-        click.echo(f"  vega web run                # Start Vega Web server (http://localhost:8000)")
-        click.echo(f"  vega web run --reload       # Start with auto-reload")
-        click.echo(f"  python main.py hello        # Run CLI command")
-        click.echo(f"  python main.py --help       # Show all commands")
-    else:
-        click.echo(f"\nRun commands:")
-        click.echo(f"  python main.py hello        # Run example CLI command")
-        click.echo(f"  python main.py greet --name John  # Run with parameters")
-        click.echo(f"  python main.py --help       # Show all commands")
+    click.echo(f"\nRun commands:")
+    click.echo(f"  vega web run                # Start Vega Web server (http://localhost:8000)")
+    click.echo(f"  vega web run --reload       # Start with auto-reload")
+    click.echo(f"  python main.py hello        # Run CLI command")
+    click.echo(f"  python main.py --help       # Show all commands")
 
     click.echo(f"\nGenerate DDD components:")
     click.echo(f"  vega generate context sales          # Create new bounded context")
